@@ -861,9 +861,12 @@ class AutoscalingClient(AbstractClient):
 
     def DetachInstances(self, request):
         """This API is used to remove CVM instances from a scaling group. Instances removed via this API will not be terminated.
-        * If the number of remaining `IN_SERVICE` instances in the scaling group is less than the minimum capacity, an error will be reported.
+        * If the number of remaining `IN_SERVICE` instances in the scaling group is less than the minimum capacity, this API will return an error.
         * However, if the scaling group is in `DISABLED` status, the removal will not verify the relationship between the number of `IN_SERVICE` instances and the minimum capacity.
 
+        This removal will unassociate the CVM from the CLB instance that has been configured for the scaling group.
+
+
         :param request: Request instance for DetachInstances.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.DetachInstancesRequest`
         :rtype: :class:`tencentcloud.autoscaling.v20180419.models.DetachInstancesResponse`
@@ -1209,9 +1212,12 @@ class AutoscalingClient(AbstractClient):
 
     def RemoveInstances(self, request):
         """This API is used to remove CVM instances from a scaling group. Instances that are automatically created through AS will be terminated, while those manually added to the scaling group will be removed and retained.
-        * If the number of remaining `IN_SERVICE` instances in the scaling group is less than the minimum capacity, an error will be reported.
+        * If the number of remaining `IN_SERVICE` instances in the scaling group is less than the minimum capacity, this API will return an error.
         * However, if the scaling group is in `DISABLED` status, the removal will not verify the relationship between the number of `IN_SERVICE` instances and the minimum capacity.
 
+        This removal will unassociate the CVM from the CLB instance that has been configured for the scaling group.
+
+
         :param request: Request instance for RemoveInstances.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.RemoveInstancesRequest`
         :rtype: :class:`tencentcloud.autoscaling.v20180419.models.RemoveInstancesResponse`
