@@ -334,6 +334,34 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeCkafkaZone(self, request):
+        """This API is used to view the availability zone (AZ) list of Ckafka.
+
+        :param request: Request instance for DescribeCkafkaZone.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DescribeCkafkaZoneRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DescribeCkafkaZoneResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeCkafkaZone", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeCkafkaZoneResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeConsumerGroup(self, request):
         """This API is used to query consumer group information.
 
@@ -530,6 +558,34 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeRegion(self, request):
+        """This API is used to enumerate regions, only including Guangzhou.
+
+        :param request: Request instance for DescribeRegion.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DescribeRegionRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DescribeRegionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeRegion", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeRegionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRoute(self, request):
         """This API is used to view route information.
 
